import * as helpers from "./modules/helpers.js";

const navigation = {
  label: "Menu",
  path: "/menu",
  command: "menu",
  depth: 0,
  submenu: {
    call: {
      label: "Call",
      path: "/menu/call",
      command: "call",
      depth: 1,
      submenu: {
        emergency: {
          label: "Emergency",
          command: "emergency",
          path: "/menu/call/emergency",
          depth: 2,
          message: "Calling Emergency",
        },
        contact1: {
          label: "Flute Inc.",
          command: "contact A",
          path: "/menu/call/contact1",
          depth: 2,
          message: "Calling Flute Inc.",
        },
        contact2: {
          label: "Brays AG",
          command: "contact B",
          path: "/menu/call/contact2",
          depth: 2,
          message: "Calling Brays AG",
        },
      },
    },
    check: {
      label: "Check",
      path: "/menu/check",
      command: "check",
      depth: 1,
      submenu: {
        daily: {
          label: "Daily",
          command: "daily",
          path: "/menu/check/daily",
          depth: 2,
          message: "Displaying Daily Checklist",
        },
        weekly: {
          label: "Weekly",
          command: "weekly",
          path: "/menu/check/weekly",
          depth: 2,
          message: "Displaying Weekly Checklist",
        },
        monthly: {
          label: "Monthly",
          command: "monthly",
          path: "/menu/check/monthly",
          depth: 2,
          message: "Displaying Monthly Checklist",
        },
      },
    },
    apps: {
      label: "Apps",
      path: "/menu/apps",
      command: "apps",
      depth: 1,
      submenu: {
        record: {
          label: "Record",
          command: "record",
          path: "/menu/apps/record",
          depth: 2,
          message: "Opening Recording App",
        },
        breakout: {
          label: "Breakout",
          command: "breakout",
          path: "/menu/apps/breakout",
          depth: 2,
          message: "Opening Breakout App",
        },
        statistics: {
          label: "Statistics",
          command: "statistics",
          path: "/menu/apps/statistics",
          depth: 2,
          message: "Opening Statistics App",
        },
      },
    },
  },
};

const backItem = {
  label: "Back",
  path: "../",
  command: "back",
};

// init application
function init() {
  // build navigation
  const appEl = document.getElementById("app");
  const navigationEl = document.createElement("nav");
  navigationEl.id = "navigation";
  const listEl = document.createElement("ul");
  navigationEl.appendChild(listEl);
  appEl.replaceChildren(navigationEl);

  resetNavigationEl();
}

function resetNavigationEl() {
  const navigationEl = document.getElementById("navigation");
  const listEl = navigationEl.querySelector("ul");
  let itemEl = buildNavigationItemEl(navigation);
  listEl.replaceChildren(itemEl);
}

// build navigation item
function buildNavigationItemEl(item) {
  const itemEl = document.createElement("li");
  const linkEl = document.createElement("a");
  linkEl.href = item.path;
  linkEl.innerHTML = item.label;
  linkEl.dataset.command = item.command;
  itemEl.appendChild(linkEl);

  linkEl.addEventListener("click", onMouseClick);

  return itemEl;
}

// on menu item mouseclick
function onMouseClick(event) {
  event.preventDefault();
  const path = event.target.getAttribute("href");
  navigateTo(path);
}

// navigate to page
function navigateTo(path) {
  if (path === "/") resetNavigationEl();
  else {
    let navObj = helpers.findNestedObject(navigation, "path", path);

    // is menu
    if (navObj.hasOwnProperty("submenu")) updateNavigation(navObj);
    else {
      //is final page
      let appEl = document.getElementById("app");
      let messageEl = document.createElement("div");
      messageEl.innerHTML = navObj.message;
      appEl.replaceChildren(messageEl);

      let exitEl = document.createElement("a");
      exitEl.href = "/";
      exitEl.innerHTML = "Exit";
      appEl.appendChild(exitEl);
    }
  }
}

// update Navigation
function updateNavigation(object) {
  // update navigation
  const listEl = document.createElement("ul");

  // is navigation
  for (let key in object.submenu) {
    let itemEl = buildNavigationItemEl(object.submenu[key]);
    listEl.appendChild(itemEl);
  }

  // add "back" button
  let backItemEl;
  if (object.depth === 0) {
    backItemEl = buildNavigationItemEl({
      label: "Close",
      path: "/",
      command: "close",
    });
  } else if (object.depth === 1) {
    backItemEl = buildNavigationItemEl({
      label: "Back",
      path: "/menu",
      command: "back",
    });
  }

  listEl.appendChild(backItemEl);

  const navigationEl = document.getElementById("navigation");
  navigationEl.replaceChildren(listEl);
}

init();
